@@ -5,7 +5,13 @@ from typing_extensions import Final
 from grapl_common.time_utils import as_millis, as_datetime
 
 SOME_DT: Final[datetime] = datetime(
-    year=2020, month=1, day=2, hour=3, minute=4, second=5, microsecond=6000,  # 6 millis
+    year=2020,
+    month=1,
+    day=2,
+    hour=3,
+    minute=4,
+    second=5,
+    microsecond=6000,  # 6 millis
 )
 
 
